@@ -29,7 +29,7 @@ class Sampler(ABC):
         """Return a state for the sampler that will be used in every other thread"""
         return
 
-    def load_state(self, state: Any):  # pylint: disable
+    def load_state(self, state: Any):
         """Load a state for the sampler shared accross threads"""
 
     def load_results(
@@ -49,7 +49,7 @@ class Sampler(ABC):
         """
         raise NotImplementedError
 
-    def load_config(self, config: Any):  # pylint: disable=no-self-use
+    def load_config(self, config: Any):
         """Transform a serialized object into a configuration object"""
         return config
 
@@ -78,25 +78,40 @@ def _load_sampled_paths(optimization_dir: Path | str, serializer, logger):
             if existing_config:
                 existing_format = existing_config[0].suffix
                 logger.warning(
-                    f"Found directory {config_dir} with file {existing_config[0].name}. But function was called with the serializer for '{serializer.SUFFIX}' files, not '{existing_format}'."
+                    f"Found directory {config_dir} with file {existing_config[0].name}. "
+                    f"But function was called with the serializer for "
+                    f"'{serializer.SUFFIX}' files, not '{existing_format}'."
                 )
             else:
-                # Should probably warn the user somehow about this, although it is not dangerous
-                logger.info(
+                # Should probably warn the user somehow about this, although it is not
+                # dangerous
+                logger.warning(
                     f"Removing {config_dir} as worker died during config sampling."
                 )
                 try:
                     shutil.rmtree(str(config_dir))
-                except Exception as e:  # The worker doesn't need to crash for this
-                    logger.error(f"Can't delete {config_dir}: {e}")
+                except Exception:  # The worker doesn't need to crash for this
+                    logger.exception(f"Can't delete {config_dir}")
+
     return previous_paths, pending_paths
 
 
-def read(optimization_dir: Path | str, serializer: str | Any = None, logger=None):
+def read(
+    optimization_dir: Path | str, serializer: str | Any = None, logger=None, do_lock=True
+):
     optimization_dir = Path(optimization_dir)
 
+    if logger is None:
+        logger = logging.getLogger("metahyper")
+
+    if do_lock:
+        decision_lock_file = optimization_dir / ".decision_lock"
+        decision_lock_file.touch(exist_ok=True)
+        decision_locker = Locker(decision_lock_file, logger.getChild("_locker"))
+        while not decision_locker.acquire_lock():
+            time.sleep(2)
+
     # Try to guess the serialization method used
-    optimization_dir = Path(optimization_dir)
     if serializer is None:
         for name, serializer_cls in SerializerMapping.items():
             data_files = [
@@ -106,16 +121,13 @@ def read(optimization_dir: Path | str, serializer: str | Any = None, logger=None
             ]
             if find_files(optimization_dir, data_files):
                 serializer = name
-                logging.info(f"Auto-detected {name} format for serializer")
+                logger.debug(f"Auto-detected {name} format for serializer")
                 break
         else:
             serializer = "json"
-            logging.info(f"Will use the {serializer} serializer as a default")
+            logger.debug(f"Will use the {serializer} serializer as a default")
 
     serializer = instance_from_map(SerializerMapping, serializer, "serializer")
-    if logger is None:
-        logger = logging.getLogger("metahyper")
-
     previous_paths, pending_paths = _load_sampled_paths(
         optimization_dir, serializer, logger
     )
@@ -144,6 +156,9 @@ def read(optimization_dir: Path | str, serializer: str | Any = None, logger=None
         f"pending_configs={pending_configs}, "
         f"and pending_configs_free={pending_configs_free}, "
     )
+
+    if do_lock:
+        decision_locker.release_lock()
     return previous_results, pending_configs, pending_configs_free
 
 
@@ -156,17 +171,14 @@ def _check_max_evaluations(
 ):
     logger.debug("Checking if max evaluations is reached")
 
-    previous_paths, pending_paths = _load_sampled_paths(
+    previous_results, pending_configs, pending_configs_free = read(
         optimization_dir, serializer, logger
     )
-    evaluation_count = len(previous_paths)
+    evaluation_count = len(previous_results)
 
     # Taking into account pending evaluations
     if not continue_until_max_evaluation_completed:
-        evaluation_count += len(pending_paths)
-
-    if evaluation_count >= max_evaluations:
-        logger.debug("Max evaluations is reached")
+        evaluation_count += len(pending_configs) - len(pending_configs_free)
 
     return evaluation_count >= max_evaluations
 
@@ -174,7 +186,7 @@ def _check_max_evaluations(
 def _sample_config(optimization_dir, sampler, serializer, logger):
     # First load the results and state of the optimizer
     previous_results, pending_configs, pending_configs_free = read(
-        optimization_dir, serializer, logger
+        optimization_dir, serializer, logger, do_lock=False
     )
     optimizer_state_file = optimization_dir / f".optimizer_state{serializer.SUFFIX}"
     if optimizer_state_file.exists():
@@ -373,4 +385,4 @@ def run(
                 config_locker.release_lock()
                 evaluations_in_this_run += 1
         else:
-            time.sleep(5)
+            time.sleep(3)
