@@ -13,7 +13,7 @@ args = parser.parse_args()
 logging.basicConfig(level=logging.WARN)
 
 previous_results, pending_configs, pending_configs_free = read(
-    args.run_directory, logging.getLogger("metahyper.status")
+    args.run_directory, logger=logging.getLogger("metahyper.status")
 )
 print(f"#Evaluated configs: {len(previous_results)}")
 print(f"#Pending configs: {len(pending_configs)}")
